import { Construct } from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface AlarmConfig {
    /**
     * Description for the topic.
     *
     * A developer-defined string that can be used to identify this topic.
     *
     * @stability stable
     */
    readonly topicDescription?: string;
    /**
     * Description for the alarm.
     *
     * A developer-defined string that can be used to identify this alarm.
     *
     * @stability stable
     */
    readonly alarmDescription: string;
    /**
     * Enter the threshold amount in USD that must be exceeded to trigger the alarm e.g. (limit: 150).
     *
     * @stability stable
     */
    readonly thresholdAmount: number;
    /**
     * The email address that will be used to subcribe to the SNS topic for billing alert notifications e.g. ['hello@example.org'] or [''hello@example.org', 'admin@example.org'].
     *
     * @default - Not configured
     * @stability stable
     */
    readonly emailAddress: string[];
    /**
     * The AWS Service to associate the alarm with e.g (AmazonDynamoDB).
     *
     * @default - Not configured.
     * @stability stable
     */
    readonly awsService?: string;
}
/**
 * @stability stable
 */
export interface MasterAccountAlarmProps {
    /**
     * Alarm configuration options to configure the AWS master/payer account billing alarm, with SNS topic or an existing Topic Arn.
     *
     * @stability stable
     */
    readonly alarmConfiguration: AlarmConfig;
    /**
     * Imports a secret by secret name e.g 'prod/billing/topicArn'.
     *
     * A secret with this name must exist in the same account & region as the master/payer AWS account.
     *
     * @stability stable
     */
    readonly secretName?: string;
}
/**
 * A construct to create a master account billing alarm in master/payer AWS account e.g (AWS Organization).
 *
 * @stability stable
 * @example
 *
 * .org'],
 * alarmDescription: 'Consolidated billing alarm for all AWS Service charges',
 * thresholdAmount: 140,
 * },
 */
export declare class MasterAccountAlarm extends Construct {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: MasterAccountAlarmProps);
    /**
     * Create billing alarm.
     *
     * @param topicArn string
     * @param AlarmParams
     */
    private createBillingAlarm;
}
